<?php

/**
 * @file commerce_spgateway_instflag.inc
 * 主要來處理信用卡的相關服務
 */

/**
 * Implements CALLBACK_commerce_payment_method_settings_form
 */

 function spgateway_instflag_settings_form($settings = NULL){
    
    $form = array();
    $options = array(
        '1' => '全部開啟',
        '3' => '分3期',
        '6' => '分6期',
        '12' => '分12期',
        '18' => '分18期',
        '24' => '分24期',
        '30' => '分30期',
    );

    $form['InstFlag'] = array(
        '#type' => 'checkboxes',
        '#title' => '可以分期的期數',
        '#description' => '選擇全部，則會直接全部開啟所有的期數',
        '#options' => $options,
        '#default_value' => empty($settings['InstFlag'])? array('1'):$settings['InstFlag'],
    );

    $form['TradeLimit'] = array(
        '#type' => 'textfield',
        '#title' => '交易限制秒數',
        '#description' => '下限為 60 秒，當秒數介於 1~59 秒時，會以 60 秒計算；上限為900秒，超過900秒會以900來記錄',
        '#size'=> 30,
        '#default_value' => empty($settings['TradeLimit'])?'60':$settings['TradeLimit'],
    );



    return $form;
 }

/**
 * Implements CALLBACK_commerce_payment_method_redirect_form
 */
function spgateway_instflag_redirect_form($form, &$form_state, $order, $payment_method) {
    
    global $base_url;

    //基本參數
    $ActionURL = SPGATEWAY_POST_SERVICE_URL;
    $HashKey = variable_get('spgatewayHashKey','K6PnjLnDPphKLc5ABLLEwKyz63DdFSW1');
    $HashIV = variable_get('spgatewayHashIV','HxUZxqAe6uUaOO4Z');

    //交易資訊
    $remote_id=date('YmdHis').$order->order_id;
    $Amount=$order->commerce_order_total['und'][0]['amount'];
    $price = commerce_currency_amount_to_decimal($Amount, 'TWD');
    $mail = $order->mail;
    $ItemDesc = variable_get('spgatewayItemDesc','使用HelloSanta模組購買商品');

    //時間限制
    $TradeLimit = isset($payment_method['settings']['TradeLimit'])?$payment_method['settings']['TradeLimit']:60; //不適用在非即時
    $ExpireDate = '';

    //分期付款
    $InstFlag = isset($payment_method['settings']['InstFlag'])?$payment_method['settings']['InstFlag']: array('1');
    if(in_array(1,$InstFlag)){
        $InstFlagParam = '1';
    }
    else{
        foreach($InstFlag as $key => $value){
            if($value == 0){
                unset($InstFlag[$key]);
            }
        }
        $InstFlagParam = implode(", ", $InstFlag);
    }

    //傳送Data
    $data = array(
        'MerchantID' => variable_get('spgatewayMerchantID','MS35530184'),
        'TradeInfo' => '',
        'TradeSha' => '',
        'Version' => '1.5',
        'RespondType' => 'JSON',
        'TimeStamp' => REQUEST_TIME,
        'LangType' => 'zh-tw',
        'MerchantOrderNo'=> $remote_id,
        'Amt' => $price,
        'ItemDesc' => $ItemDesc,
        'TradeLimit'=> $TradeLimit,
        'ExpireDate' => $ExpireDate, //非適用即時交易
        'ReturnURL' => $base_url.'/checkout/'.$order->order_id,
        'NotifyURL' => $base_url.'/checkout/'.$order->order_id.'/spgateway-notify',
        'CustomerURL' => '', //非即時交易支付方式
        'ClientBackURL' => $base_url.'/checkout/'.$order->order_id,
        'Email' => $mail,
        'EmailModify' => variable_get('spgatewayEmailModify',0), //不開放付款人電子郵件修改
        'LoginType' => variable_get('spgatewayLoginType',0), //不需要登入智付通會員
        'OrderComment' => variable_get('spgatewayOrderComment'),
        //以下開始是付款方式的參數
        'CREDIT' => 0,
        'ANDROIDPAY' => 0,
        'SAMSUNGPAY' => 0,
        'InstFlag' => $InstFlagParam,
        'CreditRed' => 0,
        'UNIONPAY' => 0,
        'WEBATM' => 0,
        'VACC' => 0,
        'CVS' => 0,
        'BARCODE' => 0,
        'P2G' => 0,
        'CVSCOM' => 0,
    );

    //加密資料
    $encrydata = spgateway_transaction_encrypt($data);
    $TradeInfo = $encrydata['TradeInfo'];
    $TradeSha = $encrydata['TradeSha'];

    $data['TradeInfo'] = $TradeInfo;
    $data['TradeSha'] = $TradeSha;

    foreach ($data as $name => $value) {
        if (!empty($value)) {
           $form[$name] = array('#type' => 'hidden', '#value' => $value);
        }
    }  
  
    $form['#action'] = $ActionURL;
    $form['submit'] = array(
        '#type' => 'submit',
        '#value' => t('Go'),
    );

    //建立交易記錄
    commerce_spgateway_create_payment_transactions($remote_id, $order, $payment_method, COMMERCE_PAYMENT_STATUS_PENDING);

    return $form;
}